package com.example.jdbcdemo.controller;

import com.example.jdbcdemo.domain.Users;
import com.example.jdbcdemo.service.UserServices;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @project_name:jdbc_demo
 * @Drscription:用户controller类，实现用户的增删改查及页面跳转
 * @author:felix.zhou
 * @date:2018-12-10 15:18
 */
@Controller
@RequestMapping("/users")
public class UserController {

    @Autowired
    private UserServices userServices;

    /**
     * @Description 查询所有用户信息
     * 访问地址：http://localhost:8080/users/findAll
     * @param model
     * @return 返回名字叫list的页面
     */
    @RequestMapping("/findAll")
    public String findAll(Model model) {
        List<Users> usersList = userServices.findAll();
        if (usersList.size() > 0) {
            System.out.println("查询所有用户成功");
        }
        model.addAttribute("userList", usersList);
        return "list";
    }

    @RequestMapping("/findById")
    public String findById(Model model, @RequestParam("user_id") int user_id) {
        Users users = userServices.findById(user_id);
        if (users!=null) {
            System.out.println("根据id查询成功");
            model.addAttribute("user", users);
            model.addAttribute("msg", "查询");
            return "details";
        } else {
            System.out.println("查询失败");
            return "error";
        }
    }

    @RequestMapping("/insert")
    public String insert() {
        System.out.println("转页面");
        return "insert";
    }

    @RequestMapping("/create")
    public String create(Model model,Users users) {
        System.out.println("新增用户");
        int result = userServices.add(users);
        if (result == 1) {
            System.out.println("新增用户成功！");
            model.addAttribute("message", "新增");
            return "success";
        } else {
            System.out.println("新增用户失败!");
            return "error";
        }
    }

    @RequestMapping("/toUpdate")
    public String toUpdate(Model model,@RequestParam("user_id") int user_id,@RequestParam("user_age") String user_age,
                           @RequestParam("user_name") String user_name) {
        System.out.println("转向更新页面");
        //保存用户信息，传递到更新页面
        model.addAttribute("user_id",user_id );
        model.addAttribute("user_age",user_age );
        model.addAttribute("user_name",user_name );
        return "update";
    }

    @RequestMapping("/update")
    public String update(Model model, Users users) {
        System.out.println("修改用户" + users);
        int result = userServices.update(users.getUser_age(),users.getUser_name(),users.getUser_id());
        if (result > 0) {
            System.out.println("修改用户成功！");
            model.addAttribute("message", "修改");
            return "success";
        } else {
            System.out.println("修改用户失败!");
            return "error";
        }
    }

    @RequestMapping("/delete")
    public String delete(Model model, @RequestParam("user_id") int user_id) {
        int result = userServices.delete(user_id);
        if (result == 1) {
            System.out.println("删除用户成功!");
            model.addAttribute("message", "删除");
            return "success";
        } else {
            System.out.println("删除用户失败!");
            return "error";
        }

    }

}
