package com.example.jdbcdemo.service.impl;

import com.example.jdbcdemo.domain.Users;
import com.example.jdbcdemo.jdbctemplate.MyRowMapper;
import com.example.jdbcdemo.service.UserServices;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @project_name:jdbc_demo
 * @Desciption:实现业务层即用户的增删改查,注意类前加注解@Service
 * @author:felix.zhou
 * @date:2018-12-10 14:49
 */
@Service
public class UserServicesImpl implements UserServices {

    @Autowired
    private JdbcTemplate jdbcTemplate;

    /**
     *@Description 查询所有用户
     * @return 返回一个list的列表
     */
    @Override
    public List<Users> findAll() {
        String sql="select * from users";
        List<Users> usersList=jdbcTemplate.query(sql,new MyRowMapper());
        return usersList;
    }

    /**
     * @Description:根据用户ID查询用户信息
     * @param id
     * @return 返回单个对象
     */

    @Override
    public Users findById(int id) {
        String sql="select * from users where user_id=?";
        Users users=jdbcTemplate.queryForObject(sql,new MyRowMapper(),id);
        return users;
    }

    /**
     * @Description:新增用户
     * @param users
     * @return 返回更新行数
     */
    @Override
    public int add(Users users) {
        String sql="insert into users(user_id,user_age,user_name) values(?,?,?)";
        int n=jdbcTemplate.update(sql,users.getUser_id(),users.getUser_age(),users.getUser_name());
        return n;
    }

    /**
     * @Description:根据用户ID修改用户信息
     * @param user_age
     * @param user_name
     * @param user_id
     * @return 返回更新行数
     */
    @Override
    public int update(int user_age, String user_name, int user_id) {
        String sql="update users set user_age=?,user_name=? where user_id=?";
        return jdbcTemplate.update(sql,user_age,user_name,user_id);

    }

    /**
     * @Description:根据用户ID删除用户信息
     * @param user_id
     * @return 返回更新行数
     */
    @Override
    public int delete(int user_id) {
        String sql="delete from users where user_id=?";
        int n=jdbcTemplate.update(sql,user_id);
        return n;
    }
}
